# YouTube Downloader V1.1.3

## Requirements

    python>=3.4
    pytube3==9.5.13

## Installation

`pip install YouTubeDownloader`

## Usage

Execute `YouTubeDownloader`

Follow the CLI instructions.

## To Do

- Allow to download all videos from a specific channel.
- Allow users to pass an URL on file call.
- Clean code.
- Create a progress bar.
- Develop tests.

### Notes

This tool has been developed merely as a learning challenge, isn't intended to have release dates.

If you liked it please share it!

Don't be shy, contribute.
